==> allura-1.8.0.tar.gz: allura-1.8.0/Allura/allura/tests/test_scripttask.py <==
#       Licensed to the Apache Software Foundation (ASF) under one
#       or more contributor license agreements.  See the NOTICE file
#       distributed with this work for additional information
#       regarding copyright ownership.  The ASF licenses this file
#       to you under the Apache License, Version 2.0 (the
#       "License"); you may not use this file except in compliance
#       with the License.  You may obtain a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#       Unless required by applicable law or agreed to in writing,
#       software distributed under the License is distributed on an
#       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
#       KIND, either express or implied.  See the License for the
#       specific language governing permissions and limitations
#       under the License.

import unittest
import mock

from allura.scripts.scripttask import ScriptTask


class TestScriptTask(unittest.TestCase):

    def setUp(self):
        class TestScriptTask(ScriptTask):
            _parser = mock.Mock()

            @classmethod
            def parser(cls):
                return cls._parser
        self.cls = TestScriptTask

    @mock.patch('allura.scripts.scripttask.sys')
    def test_arg_parsing(self, sys):
        "Make sure string of args gets correctly tokenized."
        parser = self.cls.parser()
        self.cls._execute_task('--dir "My Dir"')
        parser.parse_args.assert_called_once_with(['--dir', 'My Dir'])
        parser.reset_mock()
        self.cls._execute_task(None)
        parser.parse_args.assert_called_once_with([])

==> allura-1.16.0.tar.gz: allura-1.16.0/Allura/allura/tests/test_scripttask.py <==
#       Licensed to the Apache Software Foundation (ASF) under one
#       or more contributor license agreements.  See the NOTICE file
#       distributed with this work for additional information
#       regarding copyright ownership.  The ASF licenses this file
#       to you under the Apache License, Version 2.0 (the
#       "License"); you may not use this file except in compliance
#       with the License.  You may obtain a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#       Unless required by applicable law or agreed to in writing,
#       software distributed under the License is distributed on an
#       "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
#       KIND, either express or implied.  See the License for the
#       specific language governing permissions and limitations
#       under the License.

import unittest
import mock

from allura.scripts.scripttask import ScriptTask


class TestScriptTask(unittest.TestCase):

    def setup_method(self, method):
        class TestScriptTask(ScriptTask):
            _parser = mock.Mock()

            @classmethod
            def parser(cls):
                return cls._parser
        self.cls = TestScriptTask

    def test_arg_parsing(self):
        "Make sure string of args gets correctly tokenized."
        parser = self.cls.parser()
        self.cls._execute_task('--dir "My Dir"')
        parser.parse_args.assert_called_once_with(['--dir', 'My Dir'])
        parser.reset_mock()
        self.cls._execute_task(None)
        parser.parse_args.assert_called_once_with([])
